Initializes and runs an interactive Shiny application that demonstrates core workr functionality. The app shows workflow YAML (editable) on the left and the resulting data on the right.
Arguments
- lWorkflows
listA named list of workflows as returned byMakeWorkflowList. Defaults to all example workflows shipped with workr.- lData
listInitial named list of data objects available to workflows. Defaults tolist(value = 2, cars = datasets::cars).- lConfig
listOptional configuration hooks passed to workflow runners. Defaults to usingloadExample()forLoadData.